@@ -13,7 +13,7 @@ AnyEvent::Handle - non-blocking I/O on file handles via AnyEvent
 
 =cut
 
-our $VERSION = 4.881;
+our $VERSION = 4.9;
 
 =head1 SYNOPSIS
 
@@ -604,6 +604,16 @@ sub on_starttls {
    $_[0]{on_stoptls} = $_[1];
 }
 
+=item $handle->rbuf_max ($max_octets)
+
+Configures the C<rbuf_max> setting (C<undef> disables it).
+
+=cut
+
+sub rbuf_max {
+   $_[0]{rbuf_max} = $_[1];
+}
+
 #############################################################################
 
 =item $handle->timeout ($seconds)
@@ -986,13 +996,6 @@ sub _drain_rbuf {
    return if $self->{_skip_drain_rbuf};
    local $self->{_skip_drain_rbuf} = 1;
 
-   if (
-      defined $self->{rbuf_max}
-      && $self->{rbuf_max} < length $self->{rbuf}
-   ) {
-      $self->_error (Errno::ENOSPC, 1), return;
-   }
-
    while () {
       # we need to use a separate tls read buffer, as we must not receive data while
       # we are draining the buffer, and this can only happen with TLS.
@@ -1043,6 +1046,13 @@ sub _drain_rbuf {
       return;
    }
 
+   if (
+      defined $self->{rbuf_max}
+      && $self->{rbuf_max} < length $self->{rbuf}
+   ) {
+      $self->_error (Errno::ENOSPC, 1), return;
+   }
+
    # may need to restart read watcher
    unless ($self->{_rw}) {
       $self->start_read
